@@ -19,10 +19,10 @@ pub trait TDInputCredentials: Debug + RObject {}
 #[serde(untagged)]
 pub enum InputCredentials {
   #[doc(hidden)] _Default(()),
-  /// Applies if a user enters new credentials using Android Pay
-  AndroidPay(InputCredentialsAndroidPay),
   /// Applies if a user enters new credentials using Apple Pay
   ApplePay(InputCredentialsApplePay),
+  /// Applies if a user enters new credentials using Google Pay
+  GooglePay(InputCredentialsGooglePay),
   /// Applies if a user enters new credentials on a payment provider website
   New(InputCredentialsNew),
   /// Applies if a user chooses some previously saved payment credentials. To use their previously saved credentials, the user must have a valid temporary password
@@ -39,8 +39,8 @@ impl<'de> Deserialize<'de> for InputCredentials {
     use serde::de::Error;
     rtd_enum_deserialize!(
       InputCredentials,
-      (inputCredentialsAndroidPay, AndroidPay);
       (inputCredentialsApplePay, ApplePay);
+      (inputCredentialsGooglePay, GooglePay);
       (inputCredentialsNew, New);
       (inputCredentialsSaved, Saved);
 
@@ -51,8 +51,8 @@ impl<'de> Deserialize<'de> for InputCredentials {
 impl RObject for InputCredentials {
   #[doc(hidden)] fn td_name(&self) -> &'static str {
     match self {
-      InputCredentials::AndroidPay(t) => t.td_name(),
       InputCredentials::ApplePay(t) => t.td_name(),
+      InputCredentials::GooglePay(t) => t.td_name(),
       InputCredentials::New(t) => t.td_name(),
       InputCredentials::Saved(t) => t.td_name(),
 
@@ -61,8 +61,8 @@ impl RObject for InputCredentials {
   }
   #[doc(hidden)] fn extra(&self) -> Option<String> {
     match self {
-      InputCredentials::AndroidPay(t) => t.extra(),
       InputCredentials::ApplePay(t) => t.extra(),
+      InputCredentials::GooglePay(t) => t.extra(),
       InputCredentials::New(t) => t.extra(),
       InputCredentials::Saved(t) => t.extra(),
 
@@ -76,27 +76,27 @@ impl InputCredentials {
   pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
   #[doc(hidden)] pub fn _is_default(&self) -> bool { if let InputCredentials::_Default(_) = self { true } else { false } }
 
-  pub fn is_android_pay(&self) -> bool { if let InputCredentials::AndroidPay(_) = self { true } else { false } }
   pub fn is_apple_pay(&self) -> bool { if let InputCredentials::ApplePay(_) = self { true } else { false } }
+  pub fn is_google_pay(&self) -> bool { if let InputCredentials::GooglePay(_) = self { true } else { false } }
   pub fn is_new(&self) -> bool { if let InputCredentials::New(_) = self { true } else { false } }
   pub fn is_saved(&self) -> bool { if let InputCredentials::Saved(_) = self { true } else { false } }
 
-  pub fn on_android_pay<F: FnOnce(&InputCredentialsAndroidPay)>(&self, fnc: F) -> &Self { if let InputCredentials::AndroidPay(t) = self { fnc(t) }; self }
   pub fn on_apple_pay<F: FnOnce(&InputCredentialsApplePay)>(&self, fnc: F) -> &Self { if let InputCredentials::ApplePay(t) = self { fnc(t) }; self }
+  pub fn on_google_pay<F: FnOnce(&InputCredentialsGooglePay)>(&self, fnc: F) -> &Self { if let InputCredentials::GooglePay(t) = self { fnc(t) }; self }
   pub fn on_new<F: FnOnce(&InputCredentialsNew)>(&self, fnc: F) -> &Self { if let InputCredentials::New(t) = self { fnc(t) }; self }
   pub fn on_saved<F: FnOnce(&InputCredentialsSaved)>(&self, fnc: F) -> &Self { if let InputCredentials::Saved(t) = self { fnc(t) }; self }
 
-  pub fn as_android_pay(&self) -> Option<&InputCredentialsAndroidPay> { if let InputCredentials::AndroidPay(t) = self { return Some(t) } None }
   pub fn as_apple_pay(&self) -> Option<&InputCredentialsApplePay> { if let InputCredentials::ApplePay(t) = self { return Some(t) } None }
+  pub fn as_google_pay(&self) -> Option<&InputCredentialsGooglePay> { if let InputCredentials::GooglePay(t) = self { return Some(t) } None }
   pub fn as_new(&self) -> Option<&InputCredentialsNew> { if let InputCredentials::New(t) = self { return Some(t) } None }
   pub fn as_saved(&self) -> Option<&InputCredentialsSaved> { if let InputCredentials::Saved(t) = self { return Some(t) } None }
 
 
 
-  pub fn android_pay<T: AsRef<InputCredentialsAndroidPay>>(t: T) -> Self { InputCredentials::AndroidPay(t.as_ref().clone()) }
-
   pub fn apple_pay<T: AsRef<InputCredentialsApplePay>>(t: T) -> Self { InputCredentials::ApplePay(t.as_ref().clone()) }
 
+  pub fn google_pay<T: AsRef<InputCredentialsGooglePay>>(t: T) -> Self { InputCredentials::GooglePay(t.as_ref().clone()) }
+
   pub fn new<T: AsRef<InputCredentialsNew>>(t: T) -> Self { InputCredentials::New(t.as_ref().clone()) }
 
   pub fn saved<T: AsRef<InputCredentialsSaved>>(t: T) -> Self { InputCredentials::Saved(t.as_ref().clone()) }
@@ -113,74 +113,6 @@ impl AsRef<InputCredentials> for InputCredentials {
 
 
 
-/// Applies if a user enters new credentials using Android Pay
-#[derive(Debug, Clone, Default, Serialize, Deserialize)]
-pub struct InputCredentialsAndroidPay {
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@type", deserialize = "@type"))]
-  td_name: String,
-  #[doc(hidden)]
-  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
-  extra: Option<String>,
-  /// JSON-encoded data with the credential identifier
-  data: String,
-  
-}
-
-impl RObject for InputCredentialsAndroidPay {
-  #[doc(hidden)] fn td_name(&self) -> &'static str { "inputCredentialsAndroidPay" }
-  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
-  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
-}
-
-
-impl TDInputCredentials for InputCredentialsAndroidPay {}
-
-
-
-impl InputCredentialsAndroidPay {
-  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
-  pub fn builder() -> RTDInputCredentialsAndroidPayBuilder {
-    let mut inner = InputCredentialsAndroidPay::default();
-    inner.td_name = "inputCredentialsAndroidPay".to_string();
-    inner.extra = Some(Uuid::new_v4().to_string());
-    RTDInputCredentialsAndroidPayBuilder { inner }
-  }
-
-  pub fn data(&self) -> &String { &self.data }
-
-}
-
-#[doc(hidden)]
-pub struct RTDInputCredentialsAndroidPayBuilder {
-  inner: InputCredentialsAndroidPay
-}
-
-impl RTDInputCredentialsAndroidPayBuilder {
-  pub fn build(&self) -> InputCredentialsAndroidPay { self.inner.clone() }
-
-   
-  pub fn data<T: AsRef<str>>(&mut self, data: T) -> &mut Self {
-    self.inner.data = data.as_ref().to_string();
-    self
-  }
-
-}
-
-impl AsRef<InputCredentialsAndroidPay> for InputCredentialsAndroidPay {
-  fn as_ref(&self) -> &InputCredentialsAndroidPay { self }
-}
-
-impl AsRef<InputCredentialsAndroidPay> for RTDInputCredentialsAndroidPayBuilder {
-  fn as_ref(&self) -> &InputCredentialsAndroidPay { &self.inner }
-}
-
-
-
-
-
-
-
 /// Applies if a user enters new credentials using Apple Pay
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputCredentialsApplePay {
@@ -249,6 +181,74 @@ impl AsRef<InputCredentialsApplePay> for RTDInputCredentialsApplePayBuilder {
 
 
 
+/// Applies if a user enters new credentials using Google Pay
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct InputCredentialsGooglePay {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  /// JSON-encoded data with the credential identifier
+  data: String,
+  
+}
+
+impl RObject for InputCredentialsGooglePay {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "inputCredentialsGooglePay" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDInputCredentials for InputCredentialsGooglePay {}
+
+
+
+impl InputCredentialsGooglePay {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDInputCredentialsGooglePayBuilder {
+    let mut inner = InputCredentialsGooglePay::default();
+    inner.td_name = "inputCredentialsGooglePay".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDInputCredentialsGooglePayBuilder { inner }
+  }
+
+  pub fn data(&self) -> &String { &self.data }
+
+}
+
+#[doc(hidden)]
+pub struct RTDInputCredentialsGooglePayBuilder {
+  inner: InputCredentialsGooglePay
+}
+
+impl RTDInputCredentialsGooglePayBuilder {
+  pub fn build(&self) -> InputCredentialsGooglePay { self.inner.clone() }
+
+   
+  pub fn data<T: AsRef<str>>(&mut self, data: T) -> &mut Self {
+    self.inner.data = data.as_ref().to_string();
+    self
+  }
+
+}
+
+impl AsRef<InputCredentialsGooglePay> for InputCredentialsGooglePay {
+  fn as_ref(&self) -> &InputCredentialsGooglePay { self }
+}
+
+impl AsRef<InputCredentialsGooglePay> for RTDInputCredentialsGooglePayBuilder {
+  fn as_ref(&self) -> &InputCredentialsGooglePay { &self.inner }
+}
+
+
+
+
+
+
+
 /// Applies if a user enters new credentials on a payment provider website
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct InputCredentialsNew {
@@ -258,7 +258,7 @@ pub struct InputCredentialsNew {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Contains JSON-encoded data with a credential identifier from the payment provider
+  /// JSON-encoded data with the credential identifier from the payment provider
   data: String,
   /// True, if the credential identifier can be saved on the server side
   allow_save: bool,
