@@ -17,13 +17,13 @@ pub struct Message {
   extra: Option<String>,
   /// Message identifier; unique for the chat to which the message belongs
   id: i64,
-  /// The sender of the message
-  sender: MessageSender,
+  /// Identifier of the sender of the message
+  sender_id: MessageSender,
   /// Chat identifier
   chat_id: i64,
-  /// Information about the sending state of the message; may be null
+  /// The sending state of the message; may be null
   sending_state: Option<MessageSendingState>,
-  /// Information about the scheduling state of the message; may be null
+  /// The scheduling state of the message; may be null
   scheduling_state: Option<MessageSchedulingState>,
   /// True, if the message is outgoing
   is_outgoing: bool,
@@ -33,6 +33,8 @@ pub struct Message {
   can_be_edited: bool,
   /// True, if the message can be forwarded
   can_be_forwarded: bool,
+  /// True, if content of the message can be saved locally or copied
+  can_be_saved: bool,
   /// True, if the message can be deleted only for the current user while other users will continue to see it
   can_be_deleted_only_for_self: bool,
   /// True, if the message can be deleted for all users
@@ -41,6 +43,12 @@ pub struct Message {
   can_get_statistics: bool,
   /// True, if the message thread info is available
   can_get_message_thread: bool,
+  /// True, if chat members already viewed the message can be received through getMessageViewers
+  can_get_viewers: bool,
+  /// True, if media timestamp links can be generated for media timestamp entities in the message text, caption or web page description
+  can_get_media_timestamp_links: bool,
+  /// True, if media timestamp entities refers to a media in this message as opposed to a media in the replied message
+  has_timestamped_media: bool,
   /// True, if the message is a channel post. All messages to channels are channel posts, all other messages are not channel posts
   is_channel_post: bool,
   /// True, if the message contains an unread mention for the current user
@@ -61,13 +69,13 @@ pub struct Message {
   message_thread_id: i64,
   /// For self-destructing messages, the message's TTL (Time To Live), in seconds; 0 if none. TDLib will send updateDeleteMessages or updateMessageContent once the TTL expires
   ttl: i64,
-  /// Time left before the message expires, in seconds
+  /// Time left before the message expires, in seconds. If the TTL timer isn't started yet, equals to the value of the ttl field
   ttl_expires_in: f32,
   /// If non-zero, the user identifier of the bot through which this message was sent
   via_bot_user_id: i64,
   /// For channel posts and anonymous group messages, optional author signature
   author_signature: String,
-  /// Unique identifier of an album this message belongs to. Only photos and videos can be grouped together in albums
+  /// Unique identifier of an album this message belongs to. Only audios, documents, photos and videos can be grouped together in albums
   #[serde(deserialize_with = "serde_aux::field_attributes::deserialize_number_from_string")] media_album_id: isize,
   /// If non-empty, contains a human-readable description of the reason why access to this message must be restricted
   restriction_reason: String,
@@ -97,7 +105,7 @@ impl Message {
 
   pub fn id(&self) -> i64 { self.id }
 
-  pub fn sender(&self) -> &MessageSender { &self.sender }
+  pub fn sender_id(&self) -> &MessageSender { &self.sender_id }
 
   pub fn chat_id(&self) -> i64 { self.chat_id }
 
@@ -113,6 +121,8 @@ impl Message {
 
   pub fn can_be_forwarded(&self) -> bool { self.can_be_forwarded }
 
+  pub fn can_be_saved(&self) -> bool { self.can_be_saved }
+
   pub fn can_be_deleted_only_for_self(&self) -> bool { self.can_be_deleted_only_for_self }
 
   pub fn can_be_deleted_for_all_users(&self) -> bool { self.can_be_deleted_for_all_users }
@@ -121,6 +131,12 @@ impl Message {
 
   pub fn can_get_message_thread(&self) -> bool { self.can_get_message_thread }
 
+  pub fn can_get_viewers(&self) -> bool { self.can_get_viewers }
+
+  pub fn can_get_media_timestamp_links(&self) -> bool { self.can_get_media_timestamp_links }
+
+  pub fn has_timestamped_media(&self) -> bool { self.has_timestamped_media }
+
   pub fn is_channel_post(&self) -> bool { self.is_channel_post }
 
   pub fn contains_unread_mention(&self) -> bool { self.contains_unread_mention }
@@ -172,8 +188,8 @@ impl RTDMessageBuilder {
   }
 
    
-  pub fn sender<T: AsRef<MessageSender>>(&mut self, sender: T) -> &mut Self {
-    self.inner.sender = sender.as_ref().clone();
+  pub fn sender_id<T: AsRef<MessageSender>>(&mut self, sender_id: T) -> &mut Self {
+    self.inner.sender_id = sender_id.as_ref().clone();
     self
   }
 
@@ -220,6 +236,12 @@ impl RTDMessageBuilder {
   }
 
    
+  pub fn can_be_saved(&mut self, can_be_saved: bool) -> &mut Self {
+    self.inner.can_be_saved = can_be_saved;
+    self
+  }
+
+   
   pub fn can_be_deleted_only_for_self(&mut self, can_be_deleted_only_for_self: bool) -> &mut Self {
     self.inner.can_be_deleted_only_for_self = can_be_deleted_only_for_self;
     self
@@ -244,6 +266,24 @@ impl RTDMessageBuilder {
   }
 
    
+  pub fn can_get_viewers(&mut self, can_get_viewers: bool) -> &mut Self {
+    self.inner.can_get_viewers = can_get_viewers;
+    self
+  }
+
+   
+  pub fn can_get_media_timestamp_links(&mut self, can_get_media_timestamp_links: bool) -> &mut Self {
+    self.inner.can_get_media_timestamp_links = can_get_media_timestamp_links;
+    self
+  }
+
+   
+  pub fn has_timestamped_media(&mut self, has_timestamped_media: bool) -> &mut Self {
+    self.inner.has_timestamped_media = has_timestamped_media;
+    self
+  }
+
+   
   pub fn is_channel_post(&mut self, is_channel_post: bool) -> &mut Self {
     self.inner.is_channel_post = is_channel_post;
     self
