@@ -13,6 +13,7 @@ pub use self::_common::{
 pub use self::account_ttl::*;
 pub use self::address::*;
 pub use self::animated_chat_photo::*;
+pub use self::animated_emoji::*;
 pub use self::animation::*;
 pub use self::animations::*;
 pub use self::audio::*;
@@ -30,7 +31,8 @@ pub use self::bank_card_info::*;
 pub use self::basic_group::*;
 pub use self::basic_group_full_info::*;
 pub use self::bot_command::*;
-pub use self::bot_info::*;
+pub use self::bot_command_scope::*;
+pub use self::bot_commands::*;
 pub use self::call::*;
 pub use self::call_discard_reason::*;
 pub use self::call_id::*;
@@ -54,7 +56,15 @@ pub use self::chat_events::*;
 pub use self::chat_filter::*;
 pub use self::chat_filter_info::*;
 pub use self::chat_invite_link::*;
+pub use self::chat_invite_link_count::*;
+pub use self::chat_invite_link_counts::*;
 pub use self::chat_invite_link_info::*;
+pub use self::chat_invite_link_member::*;
+pub use self::chat_invite_link_members::*;
+pub use self::chat_invite_links::*;
+pub use self::chat_join_request::*;
+pub use self::chat_join_requests::*;
+pub use self::chat_join_requests_info::*;
 pub use self::chat_list::*;
 pub use self::chat_lists::*;
 pub use self::chat_location::*;
@@ -76,10 +86,13 @@ pub use self::chat_statistics_administrator_actions_info::*;
 pub use self::chat_statistics_inviter_info::*;
 pub use self::chat_statistics_message_interaction_info::*;
 pub use self::chat_statistics_message_sender_info::*;
+pub use self::chat_theme::*;
 pub use self::chat_type::*;
 pub use self::chats::*;
 pub use self::chats_nearby::*;
 pub use self::check_chat_username_result::*;
+pub use self::check_sticker_set_name_result::*;
+pub use self::closed_vector_path::*;
 pub use self::connected_website::*;
 pub use self::connected_websites::*;
 pub use self::connection_state::*;
@@ -111,6 +124,13 @@ pub use self::functions::*;
 pub use self::game::*;
 pub use self::game_high_score::*;
 pub use self::game_high_scores::*;
+pub use self::group_call::*;
+pub use self::group_call_id::*;
+pub use self::group_call_participant::*;
+pub use self::group_call_participant_video_info::*;
+pub use self::group_call_recent_speaker::*;
+pub use self::group_call_video_quality::*;
+pub use self::group_call_video_source_group::*;
 pub use self::hashtags::*;
 pub use self::http_url::*;
 pub use self::identity_document::*;
@@ -132,6 +152,7 @@ pub use self::input_passport_element_error_source::*;
 pub use self::input_personal_document::*;
 pub use self::input_sticker::*;
 pub use self::input_thumbnail::*;
+pub use self::internal_link_type::*;
 pub use self::invoice::*;
 pub use self::json_object_member::*;
 pub use self::json_value::*;
@@ -152,13 +173,18 @@ pub use self::login_url_info::*;
 pub use self::mask_point::*;
 pub use self::mask_position::*;
 pub use self::message::*;
+pub use self::message_calendar::*;
+pub use self::message_calendar_day::*;
 pub use self::message_content::*;
 pub use self::message_copy_options::*;
+pub use self::message_file_type::*;
 pub use self::message_forward_info::*;
 pub use self::message_forward_origin::*;
 pub use self::message_interaction_info::*;
 pub use self::message_link::*;
 pub use self::message_link_info::*;
+pub use self::message_position::*;
+pub use self::message_positions::*;
 pub use self::message_reply_info::*;
 pub use self::message_scheduling_state::*;
 pub use self::message_send_options::*;
@@ -198,6 +224,7 @@ pub use self::passport_required_element::*;
 pub use self::passport_suitable_element::*;
 pub use self::password_state::*;
 pub use self::payment_form::*;
+pub use self::payment_form_theme::*;
 pub use self::payment_receipt::*;
 pub use self::payment_result::*;
 pub use self::payments_provider_stripe::*;
@@ -207,6 +234,7 @@ pub use self::phone_number_authentication_settings::*;
 pub use self::phone_number_info::*;
 pub use self::photo::*;
 pub use self::photo_size::*;
+pub use self::point::*;
 pub use self::poll::*;
 pub use self::poll_option::*;
 pub use self::poll_type::*;
@@ -222,6 +250,7 @@ pub use self::recommended_chat_filters::*;
 pub use self::recovery_email_address::*;
 pub use self::remote_file::*;
 pub use self::reply_markup::*;
+pub use self::reset_password_result::*;
 pub use self::rich_text::*;
 pub use self::saved_credentials::*;
 pub use self::scope_notification_settings::*;
@@ -232,6 +261,7 @@ pub use self::secret_chat_state::*;
 pub use self::session::*;
 pub use self::sessions::*;
 pub use self::shipping_option::*;
+pub use self::sponsored_message::*;
 pub use self::statistical_graph::*;
 pub use self::statistical_value::*;
 pub use self::sticker::*;
@@ -265,6 +295,7 @@ pub use self::text_entities::*;
 pub use self::text_entity::*;
 pub use self::text_entity_type::*;
 pub use self::text_parse_mode::*;
+pub use self::theme_settings::*;
 pub use self::thumbnail::*;
 pub use self::thumbnail_format::*;
 pub use self::top_chat_category::*;
@@ -279,8 +310,10 @@ pub use self::user_status::*;
 pub use self::user_type::*;
 pub use self::users::*;
 pub use self::validated_order_info::*;
+pub use self::vector_path_command::*;
 pub use self::venue::*;
 pub use self::video::*;
+pub use self::video_chat::*;
 pub use self::video_note::*;
 pub use self::voice_note::*;
 pub use self::web_page::*;
@@ -292,6 +325,7 @@ pub use self::web_page_instant_view::*;
 mod account_ttl;
 mod address;
 mod animated_chat_photo;
+mod animated_emoji;
 mod animation;
 mod animations;
 mod audio;
@@ -309,7 +343,8 @@ mod bank_card_info;
 mod basic_group;
 mod basic_group_full_info;
 mod bot_command;
-mod bot_info;
+mod bot_command_scope;
+mod bot_commands;
 mod call;
 mod call_discard_reason;
 mod call_id;
@@ -333,7 +368,15 @@ mod chat_events;
 mod chat_filter;
 mod chat_filter_info;
 mod chat_invite_link;
+mod chat_invite_link_count;
+mod chat_invite_link_counts;
 mod chat_invite_link_info;
+mod chat_invite_link_member;
+mod chat_invite_link_members;
+mod chat_invite_links;
+mod chat_join_request;
+mod chat_join_requests;
+mod chat_join_requests_info;
 mod chat_list;
 mod chat_lists;
 mod chat_location;
@@ -355,10 +398,13 @@ mod chat_statistics_administrator_actions_info;
 mod chat_statistics_inviter_info;
 mod chat_statistics_message_interaction_info;
 mod chat_statistics_message_sender_info;
+mod chat_theme;
 mod chat_type;
 mod chats;
 mod chats_nearby;
 mod check_chat_username_result;
+mod check_sticker_set_name_result;
+mod closed_vector_path;
 mod connected_website;
 mod connected_websites;
 mod connection_state;
@@ -390,6 +436,13 @@ mod functions;
 mod game;
 mod game_high_score;
 mod game_high_scores;
+mod group_call;
+mod group_call_id;
+mod group_call_participant;
+mod group_call_participant_video_info;
+mod group_call_recent_speaker;
+mod group_call_video_quality;
+mod group_call_video_source_group;
 mod hashtags;
 mod http_url;
 mod identity_document;
@@ -411,6 +464,7 @@ mod input_passport_element_error_source;
 mod input_personal_document;
 mod input_sticker;
 mod input_thumbnail;
+mod internal_link_type;
 mod invoice;
 mod json_object_member;
 mod json_value;
@@ -431,13 +485,18 @@ mod login_url_info;
 mod mask_point;
 mod mask_position;
 mod message;
+mod message_calendar;
+mod message_calendar_day;
 mod message_content;
 mod message_copy_options;
+mod message_file_type;
 mod message_forward_info;
 mod message_forward_origin;
 mod message_interaction_info;
 mod message_link;
 mod message_link_info;
+mod message_position;
+mod message_positions;
 mod message_reply_info;
 mod message_scheduling_state;
 mod message_send_options;
@@ -477,6 +536,7 @@ mod passport_required_element;
 mod passport_suitable_element;
 mod password_state;
 mod payment_form;
+mod payment_form_theme;
 mod payment_receipt;
 mod payment_result;
 mod payments_provider_stripe;
@@ -486,6 +546,7 @@ mod phone_number_authentication_settings;
 mod phone_number_info;
 mod photo;
 mod photo_size;
+mod point;
 mod poll;
 mod poll_option;
 mod poll_type;
@@ -501,6 +562,7 @@ mod recommended_chat_filters;
 mod recovery_email_address;
 mod remote_file;
 mod reply_markup;
+mod reset_password_result;
 mod rich_text;
 mod saved_credentials;
 mod scope_notification_settings;
@@ -511,6 +573,7 @@ mod secret_chat_state;
 mod session;
 mod sessions;
 mod shipping_option;
+mod sponsored_message;
 mod statistical_graph;
 mod statistical_value;
 mod sticker;
@@ -544,6 +607,7 @@ mod text_entities;
 mod text_entity;
 mod text_entity_type;
 mod text_parse_mode;
+mod theme_settings;
 mod thumbnail;
 mod thumbnail_format;
 mod top_chat_category;
@@ -558,8 +622,10 @@ mod user_status;
 mod user_type;
 mod users;
 mod validated_order_info;
+mod vector_path_command;
 mod venue;
 mod video;
+mod video_chat;
 mod video_note;
 mod voice_note;
 mod web_page;
