@@ -15,12 +15,16 @@ pub struct StorageStatisticsFast {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Approximate total size of files
+  /// Approximate total size of files, in bytes
   files_size: i64,
   /// Approximate number of files
   file_count: i64,
   /// Size of the database
   database_size: i64,
+  /// Size of the language pack database
+  language_pack_database_size: i64,
+  /// Size of the TDLib internal log
+  log_size: i64,
   
 }
 
@@ -47,6 +51,10 @@ impl StorageStatisticsFast {
 
   pub fn database_size(&self) -> i64 { self.database_size }
 
+  pub fn language_pack_database_size(&self) -> i64 { self.language_pack_database_size }
+
+  pub fn log_size(&self) -> i64 { self.log_size }
+
 }
 
 #[doc(hidden)]
@@ -75,6 +83,18 @@ impl RTDStorageStatisticsFastBuilder {
     self
   }
 
+   
+  pub fn language_pack_database_size(&mut self, language_pack_database_size: i64) -> &mut Self {
+    self.inner.language_pack_database_size = language_pack_database_size;
+    self
+  }
+
+   
+  pub fn log_size(&mut self, log_size: i64) -> &mut Self {
+    self.inner.log_size = log_size;
+    self
+  }
+
 }
 
 impl AsRef<StorageStatisticsFast> for StorageStatisticsFast {
